==> lxqt-config_2.0.0.orig.tar.xz: lxqt-config-2.0.0/lxqt-config-input/translations/lxqt-config-input_lg.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lg">
<context>
    <name>KeyboardConfig</name>
    <message>
        <location filename="../keyboardconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Awajjuzibwa</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="20"/>
        <source>Cursor flash time:</source>
        <translation>Akalagakifo kamyansa buli:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="27"/>
        <source>&lt;b&gt;Keyboard&lt;/b&gt;</source>
        <translation>&lt;b&gt;Mapeesa agawandisibwa&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="34"/>
        <source>Beep when there is an error of keyboard input</source>
        <translation>Akagombe kavuge nga wazzewo kiremya ku mapeesa agawandisibwa</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="41"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="51"/>
        <source>Character Repeat</source>
        <translation>Obwangu bw&apos;enziriŋŋana y&apos;okuteekawo bubonero</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="79"/>
        <location filename="../keyboardconfig.ui" line="143"/>
        <source>Long</source>
        <translation>Kawanvu</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="108"/>
        <source>Repeat delay:</source>
        <translation>Akasirikiriro akabawo eppeesa liryoke liddemu akabonero:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="115"/>
        <location filename="../keyboardconfig.ui" line="136"/>
        <source>Short</source>
        <translation>Kampi</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="122"/>
        <source>Repeat interval:</source>
        <translation>Akaseera akayitawo eppeesa liryoke liddemu okussawo
akabonero nga erinwyezezza wansi:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="129"/>
        <source>Type in the following box to test your keyboard settings</source>
        <translation>Wandika wano olabe by&apos;otegese bwe bikola</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="150"/>
        <location filename="../keyboardconfig.ui" line="157"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="167"/>
        <source>Turn on NumLock after login</source>
        <translation>Olutandika olutuula ne NumLock ebeereko</translation>
    </message>
</context>
<context>
    <name>KeyboardLayoutConfig</name>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="20"/>
        <source>&lt;b&gt;Keyboard Layout&lt;/b&gt;</source>
        <translation>&lt;b&gt;Entereeza y&apos;amapeesa agawandisibwa&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="48"/>
        <source>Layout</source>
        <translation>Entereeza</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="53"/>
        <source>Variant</source>
        <translation>Enkyuka ezigy&apos;ongedwako</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="63"/>
        <source>&amp;Add</source>
        <translation>&amp;Yongerako</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="70"/>
        <source>&amp;Remove</source>
        <translation>&amp;Gyawo</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="77"/>
        <source>Up</source>
        <translation>Yambusa</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="84"/>
        <source>Down</source>
        <translation>Ssa</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="108"/>
        <source>Keyboard model:</source>
        <translation>Kika ky&apos;amapeesa agawandisibwa:</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="122"/>
        <source>Keys to change layout:</source>
        <translation>Amapeesa agakyusa entereeza:</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="133"/>
        <source>None</source>
        <translation>Tewali</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="141"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note&lt;/span&gt;: If you are using an &lt;span style=&quot; font-weight:600;&quot;&gt;input method&lt;/span&gt;, such as IBus, uim, fcitx, or gcin, the settings here &lt;span style=&quot; font-weight:600;&quot;&gt;might not work&lt;/span&gt; because they are overridden by the input methods.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Genderera&lt;/span&gt;:&lt;br&gt;Bw&apos;obanga okozesa &lt;span style=&quot; font-weight:600;&quot;&gt;empandika y&apos;ennukuta&lt;/span&gt; nga IBus, uim, fcitx, oba gcin,&lt;br&gt;ebitegekebwa wano &lt;span style=&quot; font-weight:600;&quot;&gt;biyinza obutakola&lt;/span&gt; nga ebiva mu mpandika z&apos;ennukuta ezo bye bizzewo.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>MouseConfig</name>
    <message>
        <location filename="../mouseconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Awajjuzibwa</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="23"/>
        <source>&lt;b&gt;Mouse&lt;/b&gt;</source>
        <translation>&lt;b&gt;Akasongesebwa&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="30"/>
        <source>Double click interval:</source>
        <translation>Ebbanga wakati w&apos;ennyiga bbiri zibalibwe ng&apos;eziri okumu:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="37"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="47"/>
        <source>Wheel scroll lines:</source>
        <translation>Ennyiriri z&apos;ekiwandike eziseesebwa buli kipimo ky&apos;okunyoola namuziga:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="64"/>
        <source>Left handed (Swap left and right mouse buttons)</source>
        <translation>Muwandisa kkono (wanyisa enkola y&apos;amapeesa ga kkono ne ddyo)</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="57"/>
        <source>Single click to activate items</source>
        <translation>Amapeesa gakolere ku lukoona lumu</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../lxqt-config-input.cpp" line="70"/>
        <source>Keyboard and Mouse Settings</source>
        <translation>Enteekateeka z&apos;akasongesebwa n&apos;amapeesa agwandisibwa</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="79"/>
        <source>Mouse</source>
        <translation>Akasongesebwa</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="88"/>
        <source>Cursor</source>
        <translation>Akasonga</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="95"/>
        <source>Keyboard</source>
        <translation>Mapeesa agawandisibwa</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="103"/>
        <source>Keyboard Layout</source>
        <translation>Entereeza y&apos;amapeesa agawandisibwa</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="112"/>
        <source>Mouse and Touchpad</source>
        <translation>Akasongesebwa aka bulijjo n&apos;akasiisirizibwa</translation>
    </message>
</context>
<context>
    <name>SelectKeyboardLayoutDialog</name>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="14"/>
        <source>Select a keyboard layout</source>
        <translation>Londa entereeza y&apos;amapeesa agawandiksibwa</translation>
    </message>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="20"/>
        <source>Keyboard layout</source>
        <translation>Entereeza y&apos;amapeesa agawandiksibwa</translation>
    </message>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="27"/>
        <source>Variant</source>
        <translation>Enkyuka ezigy&apos;ongedwako</translation>
    </message>
</context>
<context>
    <name>TouchpadConfig</name>
    <message>
        <location filename="../touchpadconfig.ui" line="14"/>
        <source>TouchpadConfig </source>
        <translation>Enteekateeka z&apos;aksongesebwa akasiisirizibwa </translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="20"/>
        <source>Device:</source>
        <translation>Kyuma:</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="30"/>
        <source>Acceleration speed:</source>
        <translation>Enyanguwa y&apos;akasonga:</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="37"/>
        <source>Tap to click</source>
        <translation>Koonesa kagalo okubeera nga anyize ppeesa</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="44"/>
        <source>Natural Scrolling</source>
        <translation>Enseesa esuubirwa</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="51"/>
        <source>Tap and drag</source>
        <translation>Koona okusobola okuwalula</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="79"/>
        <source>Scrolling:</source>
        <translation>Okuseesa:</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="102"/>
        <source>&amp;Disabled</source>
        <translation>&amp;Kusibidwa</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="109"/>
        <source>&amp;Two-Finger</source>
        <translation>Kwa ngalo &amp;bbiri</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="116"/>
        <source>Ed&amp;ge</source>
        <translation>&amp;Lugalo ku njegoyego</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="123"/>
        <source>B&amp;utton</source>
        <translation>&amp;Ppeesa</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="145"/>
        <source>DeviceInfoLabel</source>
        <translation>Ebikwata ku kyuma</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.cpp" line="85"/>
        <source>LXQt only supports &quot;libinput&quot; as xinput driver.
(current value: %1)

If this is intended, please configure xinput manually.
Otherwise you can get rid of this message by changing xinput driver to &quot;libinput&quot;.
</source>
        <translation>Puloguramu &quot;libinput&quot; yokka LXQt gy&apos;ekozesa okugitabaganya ne xinput.
(kaakano waliwo: %1)

Ekiriwo bwe kiba nga okigenderedde, xinput kyetaagisa okugyeteekateekera.
Bwe kiba nga ssi ky&apos;ogenderedde kyusa akatabaganya LXQt ne xinput kabeere &quot;libinput&quot;.
</translation>
    </message>
</context>
</TS>

==> lxqt-config_2.1.1.orig.tar.xz: lxqt-config-2.1.1/lxqt-config-input/translations/lxqt-config-input_lg.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lg">
<context>
    <name>KeyboardConfig</name>
    <message>
        <location filename="../keyboardconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Awajjuzibwa</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="143"/>
        <source>Cursor flash time:</source>
        <translation>Akalagakifo kamyansa buli:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="20"/>
        <source>&lt;b&gt;Keyboard&lt;/b&gt;</source>
        <translation>&lt;b&gt;Mapeesa agawandisibwa&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="160"/>
        <source>Beep when there is an error of keyboard input</source>
        <translation>Akagombe kavuge nga wazzewo kiremya ku mapeesa agawandisibwa</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="150"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="27"/>
        <source>Character Repeat</source>
        <translation>Obwangu bw&apos;enziriŋŋana y&apos;okuteekawo bubonero</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="69"/>
        <location filename="../keyboardconfig.ui" line="116"/>
        <source>Long</source>
        <translation>Kawanvu</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="33"/>
        <source>Repeat delay:</source>
        <translation>Akasirikiriro akabawo eppeesa liryoke liddemu akabonero:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="40"/>
        <location filename="../keyboardconfig.ui" line="90"/>
        <source>Short</source>
        <translation>Kampi</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="83"/>
        <source>Repeat interval:</source>
        <translation>Akaseera akayitawo eppeesa liryoke liddemu okussawo
akabonero nga erinwyezezza wansi:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="130"/>
        <source>Type in the following box to test your keyboard settings</source>
        <translation>Wandika wano olabe by&apos;otegese bwe bikola</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="76"/>
        <location filename="../keyboardconfig.ui" line="123"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="167"/>
        <source>Turn on NumLock after login</source>
        <translation>Olutandika olutuula ne NumLock ebeereko</translation>
    </message>
</context>
<context>
    <name>KeyboardLayoutConfig</name>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="20"/>
        <source>&lt;b&gt;Keyboard Layout&lt;/b&gt;</source>
        <translation>&lt;b&gt;Entereeza y&apos;amapeesa agawandisibwa&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="48"/>
        <source>Layout</source>
        <translation>Entereeza</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="53"/>
        <source>Variant</source>
        <translation>Enkyuka ezigy&apos;ongedwako</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="63"/>
        <source>&amp;Add</source>
        <translation>&amp;Yongerako</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="70"/>
        <source>&amp;Remove</source>
        <translation>&amp;Gyawo</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="77"/>
        <source>Up</source>
        <translation>Yambusa</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="84"/>
        <source>Down</source>
        <translation>Ssa</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="108"/>
        <source>Keyboard model:</source>
        <translation>Kika ky&apos;amapeesa agawandisibwa:</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="122"/>
        <source>Keys to change layout:</source>
        <translation>Amapeesa agakyusa entereeza:</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="133"/>
        <source>None</source>
        <translation>Tewali</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="141"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note&lt;/span&gt;: If you are using an &lt;span style=&quot; font-weight:600;&quot;&gt;input method&lt;/span&gt;, such as IBus, uim, fcitx, or gcin, the settings here &lt;span style=&quot; font-weight:600;&quot;&gt;might not work&lt;/span&gt; because they are overridden by the input methods.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Genderera&lt;/span&gt;:&lt;br&gt;Bw&apos;obanga okozesa &lt;span style=&quot; font-weight:600;&quot;&gt;empandika y&apos;ennukuta&lt;/span&gt; nga IBus, uim, fcitx, oba gcin,&lt;br&gt;ebitegekebwa wano &lt;span style=&quot; font-weight:600;&quot;&gt;biyinza obutakola&lt;/span&gt; nga ebiva mu mpandika z&apos;ennukuta ezo bye bizzewo.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>MouseConfig</name>
    <message>
        <location filename="../mouseconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Awajjuzibwa</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="23"/>
        <source>&lt;b&gt;Mouse&lt;/b&gt;</source>
        <translation>&lt;b&gt;Akasongesebwa&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="30"/>
        <source>Double click interval:</source>
        <translation>Ebbanga wakati w&apos;ennyiga bbiri zibalibwe ng&apos;eziri okumu:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="37"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="47"/>
        <source>Wheel scroll lines:</source>
        <translation>Ennyiriri z&apos;ekiwandike eziseesebwa buli kipimo ky&apos;okunyoola namuziga:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="64"/>
        <source>Left handed (Swap left and right mouse buttons)</source>
        <translation>Muwandisa kkono (wanyisa enkola y&apos;amapeesa ga kkono ne ddyo)</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="57"/>
        <source>Single click to activate items</source>
        <translation>Amapeesa gakolere ku lukoona lumu</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../lxqt-config-input.cpp" line="38"/>
        <source>LXQt input settings are currently unsupported under Wayland.

Mouse, touchpad and keyboard can be configured in the settings of the compositor.</source>
        <translation>Kakano LXQt tekusobozesa okukola ku nteekateeka z&apos;ebikozesebwa okuyingiza nga Wayland y&apos;ekola.

Enteekateeka ez&apos;akasongesebwa aka bulijjo n&apos;akasiisirizibwa ne ez&apos;amapeesa agawandiksibwa osobola okuzikolerako w&apos;otegekera ebya puloguramu ekwanaganya ebirabikira awakolerwa.</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="77"/>
        <source>Platform Unsupported</source>
        <translation>Tewali nkolagana ne sisitemu</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="81"/>
        <source>Keyboard and Mouse Settings</source>
        <translation>Enteekateeka z&apos;akasongesebwa n&apos;amapeesa agwandisibwa</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="90"/>
        <source>Mouse</source>
        <translation>Akasongesebwa</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="99"/>
        <source>Cursor</source>
        <translation>Akasonga</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="106"/>
        <source>Keyboard</source>
        <translation>Mapeesa agawandisibwa</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="114"/>
        <source>Keyboard Layout</source>
        <translation>Entereeza y&apos;amapeesa agawandisibwa</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="123"/>
        <source>Mouse and Touchpad</source>
        <translation>Akasongesebwa aka bulijjo n&apos;akasiisirizibwa</translation>
    </message>
</context>
<context>
    <name>SelectKeyboardLayoutDialog</name>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="14"/>
        <source>Select a keyboard layout</source>
        <translation>Londa entereeza y&apos;amapeesa agawandiksibwa</translation>
    </message>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="20"/>
        <source>Keyboard layout</source>
        <translation>Entereeza y&apos;amapeesa agawandiksibwa</translation>
    </message>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="27"/>
        <source>Variant</source>
        <translation>Enkyuka ezigy&apos;ongedwako</translation>
    </message>
</context>
<context>
    <name>TouchpadConfig</name>
    <message>
        <location filename="../touchpadconfig.ui" line="14"/>
        <source>TouchpadConfig </source>
        <translation>Enteekateeka z&apos;aksongesebwa akasiisirizibwa </translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="20"/>
        <source>Device:</source>
        <translation>Kyuma:</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="37"/>
        <source>Acceleration speed:</source>
        <translation>Enyanguwa y&apos;akasonga:</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="60"/>
        <source>Tap to click</source>
        <translation>Koonesa kagalo okubeera nga anyize ppeesa</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="67"/>
        <source>Natural Scrolling</source>
        <translation>Enseesa esuubirwa</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="74"/>
        <source>Tap and drag</source>
        <translation>Koona okusobola okuwalula</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="86"/>
        <source>Scrolling:</source>
        <translation>Okuseesa:</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="109"/>
        <source>&amp;Disabled</source>
        <translation>&amp;Kusibidwa</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="116"/>
        <source>&amp;Two-Finger</source>
        <translation>Kwa ngalo &amp;bbiri</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="123"/>
        <source>Ed&amp;ge</source>
        <translation>&amp;Lugalo ku njegoyego</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="130"/>
        <source>B&amp;utton</source>
        <translation>&amp;Ppeesa</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="30"/>
        <source>DeviceInfoLabel</source>
        <translation>Ebikwata ku kyuma</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.cpp" line="85"/>
        <source>LXQt only supports &quot;libinput&quot; as xinput driver.
(current value: %1)

If this is intended, please configure xinput manually.
Otherwise you can get rid of this message by changing xinput driver to &quot;libinput&quot;.
</source>
        <translation>Puloguramu &quot;libinput&quot; yokka LXQt gy&apos;ekozesa okugitabaganya ne xinput.
(kaakano waliwo: %1)

Ekiriwo bwe kiba nga okigenderedde, xinput kyetaagisa okugyeteekateekera.
Bwe kiba nga ssi ky&apos;ogenderedde kyusa akatabaganya LXQt ne xinput kabeere &quot;libinput&quot;.
</translation>
    </message>
</context>
</TS>
